==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/it_it/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = 'I vecchi registri Cron di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = 'I vecchi registri delle transazioni di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = 'I vecchi registri di servizio di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = 'I vecchi registri delle impostazioni del client di %1$s sono stati eliminati.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = 'I vecchi registri utente di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = 'I vecchi registri di Messenger di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = 'I vecchi registri e-mail di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = 'I vecchi registri dei contatti di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = 'I vecchi registri di accesso all\'account di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = 'I vecchi registri del modulo di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = 'I vecchi registri di Gateway di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.completed'] = 'L\'attività di pulizia dei registri è stata completata.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Tentativo di ripulire i vecchi registri.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/it_it/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = 'I vecchi registri Cron di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = 'I vecchi registri delle transazioni di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = 'I vecchi registri di servizio di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = 'I vecchi registri delle impostazioni del client di %1$s sono stati eliminati.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = 'I vecchi registri utente di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = 'I vecchi registri di Messenger di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = 'I vecchi registri e-mail di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = 'I vecchi registri dei contatti di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = 'I vecchi registri di accesso all\'account di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = 'I vecchi registri del modulo di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = 'I vecchi registri di Gateway di %1$s sono stati cancellati.';
$lang['Automation.task.cleanup_logs.completed'] = 'L\'attività di pulizia dei registri è stata completata.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Tentativo di ripulire i vecchi registri.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s I vecchi registri delle modifiche al servizio sono stati eliminati.';
